summaryrefslogtreecommitdiff
path: root/gpsmon.c
diff options
context:
space:
mode:
Diffstat (limited to 'gpsmon.c')
-rw-r--r--gpsmon.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/gpsmon.c b/gpsmon.c
index 8a35138e..99b97788 100644
--- a/gpsmon.c
+++ b/gpsmon.c
@@ -1297,11 +1297,12 @@ int main(int argc, char **argv)
if (session.sourcetype == source_rs232 || session.sourcetype == source_usb) {
session.pps_thread.report_hook = pps_report;
/*
* The Raspberry Pi kludge. If we're using /dev/ttyAMA0,
* and there is a static /dev/pps0, and we have access because
* we're root, assume we want to use KPPS.
*/
- if (strcmp(session.pps_thread.devicename, "/dev/ttyAMA0") == 0
+ if (strcmp(session.pps_thread.devicename, MAGIC_HAT_GPS) == 0
&& access("/dev/pps0", R_OK | W_OK) == 0)
session.pps_thread.devicename = "/dev/pps0";
pps_thread_activate(&session.pps_thread);
@@ -1297,11 +1297,12 @@ int main(int argc, char **argv)
session.pps_thread.report_hook = pps_report;
/*
- * The Raspberry Pi kludge. If we're using /dev/ttyAMA0,
- * and there is a static /dev/pps0, and we have access because
- * we're root, assume we want to use KPPS.
+ * The HAT kludge. If we're using the HAT GPS on a
+ * Raspberry Pi or a workalike like the ODROIDC2, and
+ * there is a static /dev/pps0, and we have access because
+ * we're root, assume we want to use KPPS.
*/